[network-manager-applet] gsm: don't care about PIN2 yet either



commit 2cb37d2faf400a8ceabd6726253b297d05c660f0
Author: Dan Williams <dcbw redhat com>
Date:   Fri Mar 19 11:10:16 2010 -0700

    gsm: don't care about PIN2 yet either

 src/applet-device-gsm.c |    4 ++--
 1 files changed, 2 insertions(+), 2 deletions(-)
---
diff --git a/src/applet-device-gsm.c b/src/applet-device-gsm.c
index 413dfe0..9644876 100644
--- a/src/applet-device-gsm.c
+++ b/src/applet-device-gsm.c
@@ -1218,10 +1218,10 @@ parse_unlock_required (GValue *value)
 	/* Empty string means NULL */
 	new_val = g_value_get_string (value);
 	if (new_val && strlen (new_val)) {
 		/* PUK2 only required for various dialing things that we don't care
 		 * about; it doesn't inhibit normal operation.
 		 */
-		if (strcmp (new_val, "sim-puk2") != 0)
+		if (strcmp (new_val, "sim-puk2") && strcmp (new_val, "sim-pin2"))
 			return g_strdup (new_val);
 	}
 
@@ -1218,10 +1218,10 @@ parse_unlock_required (GValue *value)
 	new_val = g_value_get_string (value);
 	if (new_val && strlen (new_val)) {
-		/* PUK2 only required for various dialing things that we don't care
+		/* PIN2/PUK2 only required for various dialing things that we don't care
 		 * about; it doesn't inhibit normal operation.
 		 */



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]